import { ApplicationRef, Component, ComponentFactoryResolver, Inject, Injectable, Injector, Input, NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';
import { NgbActiveModal, NgbModal, NgbModule } from '@ng-bootstrap/ng-bootstrap';
import { HttpClient, HttpClientModule, HttpParams } from '@angular/common/http';
import { FacebookInitializerService, FacebookInviteService, FacebookLoginService, FriendsService, GameCacheService, JTBCoreGamesUI, MessageBusService, Player, PlayerService } from 'jtb-core-games-ui';
import { FormsModule } from '@angular/forms';
import { Subject as Subject$1 } from 'rxjs/Subject';
import { NavigationEnd, Router } from '@angular/router';
import { MultiSelectModule } from 'primeng/primeng';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var AdminComponent = (function () {
    function AdminComponent() {
    }
    AdminComponent.decorators = [
        { type: Component, args: [{
                    selector: 'admin-screen',
                    template: "<div class=\"admin-screen\"> <ngb-tabset type=\"pills\"> <ngb-tab title=\"Stats\"> <ng-template ngbTabContent> <admin-stats></admin-stats> </ng-template> </ngb-tab> <ngb-tab title=\"Switch player\"> <ng-template ngbTabContent> <admin-switch-player></admin-switch-player> </ng-template> </ngb-tab> </ngb-tabset> </div>",
                    styles: [".admin-screen { margin-top: 5px; } .admin-screen button { width: 100%; } .admin-screen table { margin-top: 20px; } "]
                },] },
    ];
    /** @nocollapse */
    AdminComponent.ctorParameters = function () { return []; };
    return AdminComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var AdminStatsComponent = (function () {
    function AdminStatsComponent(http$$1) {
        var _this = this;
        this.http = http$$1;
        this.playerCount = 0;
        this.gameCount = 0;
        this.gamesCreated = [0, 0, 0];
        this.playersCreated = [0, 0, 0];
        this.playerLogins = [0, 0, 0];
        this.time = Math.floor((new Date()).getTime() / 1000);
        this.times = [
            (this.time - AdminStatsComponent.dayInSeconds),
            (this.time - (AdminStatsComponent.dayInSeconds * 7)),
            (this.time - (AdminStatsComponent.dayInSeconds * 30))
        ];
        this.times.forEach(function (time, index) {
            _this.http.get('/api/player/admin/playersCreated/' + time, { responseType: 'text' })
                .subscribe(function (text) {
                _this.playersCreated[index] = Number(text);
            });
            _this.http.get('/api/player/admin/playersLoggedIn/' + time, { responseType: 'text' })
                .subscribe(function (text) {
                _this.playerLogins[index] = Number(text);
            });
            _this.http.get('/api/player/admin/gamesSince/' + time, { responseType: 'text' })
                .subscribe(function (text) {
                _this.gamesCreated[index] = Number(text);
            });
        });
        this.http.get('/api/player/admin/gameCount', { responseType: 'text' })
            .subscribe(function (text) {
            _this.gameCount = Number(text);
        });
        this.http.get('/api/player/admin/playerCount', { responseType: 'text' })
            .subscribe(function (text) {
            _this.playerCount = Number(text);
        });
    }
    AdminStatsComponent.dayInSeconds = 86400;
    AdminStatsComponent.decorators = [
        { type: Component, args: [{
                    selector: 'admin-stats',
                    template: "<div class=\"admin-stats\"> <table class=\"table table-striped table-sm table-admin-states\"> <tr> <th></th> <th class=\"text-right\">Last 24 hours</th> <th class=\"text-right\">Last 7 days</th> <th class=\"text-right\">Last 30 days</th> <th class=\"text-right\">All</th> </tr> <tr class=\"text-right\"> <th class=\"text-left\">Games</th> <td>{{gamesCreated[0]}}</td> <td>{{gamesCreated[1]}}</td> <td>{{gamesCreated[2]}}</td> <td>{{gameCount}}</td> </tr> <tr class=\"text-right\"> <th class=\"text-left\">Players Created</th> <td>{{playersCreated[0]}}</td> <td>{{playersCreated[1]}}</td> <td>{{playersCreated[2]}}</td> <td>{{playerCount}}</td> </tr> <tr class=\"text-right\"> <th class=\"text-left\">Players Logged In</th> <td>{{playerLogins[0]}}</td> <td>{{playerLogins[1]}}</td> <td>{{playerLogins[2]}}</td> <td></td> </tr> </table> </div> ",
                },] },
    ];
    /** @nocollapse */
    AdminStatsComponent.ctorParameters = function () { return [
        { type: HttpClient, },
    ]; };
    return AdminStatsComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var AdminSwitchPlayerComponent = (function () {
    function AdminSwitchPlayerComponent(playerService, http$$1) {
        var _this = this;
        this.playerService = playerService;
        this.http = http$$1;
        this.revertText = '';
        this.revertEnabled = false;
        this.searchText = '';
        this.players = [];
        this.pageSize = 20;
        this.totalPlayers = 0;
        this.currentPage = 1;
        this.playerService.player.subscribe(function (p) {
            _this.player = p;
            _this.computeRevert();
        });
        this.playerService.loggedInPlayer.subscribe(function (p) {
            _this.loggedInPlayer = p;
            _this.computeRevert();
        });
        this.refreshUsers();
    }
    /**
     * @param {?} id
     * @return {?}
     */
    AdminSwitchPlayerComponent.prototype.switchToPlayer = /**
     * @param {?} id
     * @return {?}
     */
    function (id) {
        this.playerService.simulateUser(id);
    };
    /**
     * @return {?}
     */
    AdminSwitchPlayerComponent.prototype.revertToNormal = /**
     * @return {?}
     */
    function () {
        this.playerService.simulateUser(this.loggedInPlayer.id);
    };
    /**
     * @return {?}
     */
    AdminSwitchPlayerComponent.prototype.changePage = /**
     * @return {?}
     */
    function () {
        this.refreshUsers();
    };
    /**
     * @return {?}
     */
    AdminSwitchPlayerComponent.prototype.refreshUsers = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.http.get('/api/player/admin/playersLike', {
            params: new HttpParams().set('page', String(this.currentPage - 1)).set('like', this.searchText).set('pageSize', String(this.pageSize))
        }).subscribe(function (json) {
            _this.processUsers(json);
        });
    };
    /**
     * @param {?} json
     * @return {?}
     */
    AdminSwitchPlayerComponent.prototype.processUsers = /**
     * @param {?} json
     * @return {?}
     */
    function (json) {
        //noinspection TypeScriptUnresolvedVariable
        this.totalPlayers = json.totalElements;
        // controller.numberOfPages = response.totalPages;
        var /** @type {?} */ newPlayers = [];
        json.content.forEach(function (p) {
            newPlayers.push(new Player(p));
        });
        this.players = newPlayers;
        this.currentPage = json.number + 1;
    };
    /**
     * @return {?}
     */
    AdminSwitchPlayerComponent.prototype.computeRevert = /**
     * @return {?}
     */
    function () {
        this.revertEnabled = (this.player && this.loggedInPlayer && this.player.id !== this.loggedInPlayer.id);
        this.revertText = this.revertEnabled ?
            'You are simulating another player.' :
            'You are yourself.';
    };
    AdminSwitchPlayerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'admin-switch-player',
                    template: "<div class=\"admin-user\"> <div class=\"row\"> <div class=\"col-4\"> <button class=\"btn btn-secondary btn-success btn-stop-simulating\" [disabled]=\"!revertEnabled\" (click)=\"revertToNormal()\">Stop </button> </div> <div class=\"col-8\">{{revertText}}</div> </div> <div class=\"row\"> <div class=\"col-4\"> <button class=\"btn btn-default focus btn-primary btn-get-users\" (click)=\"refreshUsers()\">Get Users </button> </div> <div class=\"col-8\"> <input class=\"form-control\" type=\"text\" [(ngModel)]=\"searchText\" placeholder=\"And Name contains..\"> </div> </div> <div class=\"row\"> <div class=\"col\"> <table class=\"table table-striped table-sm table-admin-users\"> <tr> <th>Display Name</th> <th>ID</th> <th>Switch</th> </tr> <tr *ngFor=\"let player of players\"> <td>{{player.displayName}}</td> <td>{{player.id}}</td> <td> <button class=\"btn btn-danger btn-danger btn-change-user\" id=\"{{player.id}}\" (click)=\"switchToPlayer(player.id)\">Switch to this user.. </button> </td> </tr> </table> </div> </div> <div class=\"row\"> <div class=\"col\"> <ngb-pagination [pageSize]=\"pageSize\" [directionLinks]=\"false\" [collectionSize]=\"totalPlayers\" [(page)]=\"currentPage\" (pageChange)=\"changePage()\"> </ngb-pagination> </div> </div> </div> ",
                },] },
    ];
    /** @nocollapse */
    AdminSwitchPlayerComponent.ctorParameters = function () { return [
        { type: PlayerService, },
        { type: HttpClient, },
    ]; };
    return AdminSwitchPlayerComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBCoreGamesUIBSAdminModule = (function () {
    function JTBCoreGamesUIBSAdminModule() {
    }
    JTBCoreGamesUIBSAdminModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        BrowserModule,
                        NgbModule,
                        FormsModule,
                        HttpClientModule,
                        JTBCoreGamesUI
                    ],
                    exports: [
                        AdminComponent
                    ],
                    declarations: [
                        AdminComponent,
                        AdminStatsComponent,
                        AdminSwitchPlayerComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBSAdminModule.ctorParameters = function () { return []; };
    return JTBCoreGamesUIBSAdminModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SignInComponent = (function () {
    function SignInComponent(facebookLogin, facebookInit, window) {
        var _this = this;
        this.facebookLogin = facebookLogin;
        this.facebookInit = facebookInit;
        this.window = window;
        this.message = '';
        this.showManual = false;
        this.showFacebook = false;
        this.showManual = true;
        this.showFacebook = false;
        this.facebookInit.fbReady.then(function () {
            _this.showFacebook = true;
        });
        this.facebookLogin.canAutoLogin.subscribe(function (can) {
            if (can) {
                _this.autoLogin();
            }
        });
    }
    /**
     * @return {?}
     */
    SignInComponent.prototype.fbLogin = /**
     * @return {?}
     */
    function () {
        this.facebookLogin.initiateLogin();
    };
    /**
     * @return {?}
     */
    SignInComponent.prototype.autoLogin = /**
     * @return {?}
     */
    function () {
        this.showFacebook = false;
        this.showManual = false;
        this.message = 'Logging in via Facebook';
        this.window.location.href = '/auth/facebook';
    };
    SignInComponent.decorators = [
        { type: Component, args: [{
                    selector: 'sign-in',
                    template: "<div class=\"sign-in\"> <div id=\"sign-in-message\" class=\"container-fluid\"> <div class=\"row text-center\"> <div class=\"col\"> <p>{{message}}</p> </div> </div> </div> <div id=\"sign-in-facebook\" class=\"container-fluid\" *ngIf=\"showFacebook\"> <div class=\"row text-center\"> <div class=\"col\"> <a href=\"javascript:void(0)\" id=\"fb-login\" (click)=\"fbLogin()\"><img src=\"../../../images/sign-in-with-facebook.png\"/></a> </div> </div> </div> <div id=\"sign-in-manual\" class=\"container-fluid\" *ngIf=\"showManual\"> <div class=\"row text-center\"> <div class=\"col\"> <p>Don't want to login with Facebook?</p> <!--suppress HtmlUnknownTarget --> <form id=\"signin\" action=\"/signin/authenticate\" method=\"post\" class=\"form-group\"> <div class=\"form-group\"> <label for=\"username\">Username</label> <input id=\"username\" name=\"username\" type=\"text\" size=\"25\"/> </div> <div class=\"form-group\"> <label for=\"password\">Password</label> <input id=\"password\" name=\"password\" type=\"password\" size=\"25\"/> </div> <div class=\"form-group\"> <div class=\"checkbox\"> <label> <input type=\"checkbox\" id=\"remember-me\" name=\"remember-me\"> Remember me </label> </div> </div> <div class=\"form-group\"> <button type=\"submit\" class=\"btn btn-default\">Sign in</button> </div> </form> </div> </div> </div> </div> ",
                },] },
    ];
    /** @nocollapse */
    SignInComponent.ctorParameters = function () { return [
        { type: FacebookLoginService, },
        { type: FacebookInitializerService, },
        { type: undefined, decorators: [{ type: Inject, args: ['Window',] },] },
    ]; };
    return SignInComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ɵ0 = window;
var JTBCoreGamesUIBSSignInModule = (function () {
    function JTBCoreGamesUIBSSignInModule() {
    }
    JTBCoreGamesUIBSSignInModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        BrowserModule,
                        NgbModule,
                        JTBCoreGamesUI
                    ],
                    providers: [
                        { provide: 'Window', useValue: ɵ0 }
                    ],
                    exports: [
                        SignInComponent
                    ],
                    declarations: [
                        SignInComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBSSignInModule.ctorParameters = function () { return []; };
    return JTBCoreGamesUIBSSignInModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var DefaultActionErrorComponent = (function () {
    function DefaultActionErrorComponent(activeModal) {
        this.activeModal = activeModal;
    }
    DefaultActionErrorComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngbd-modal-content',
                    template: "<div class=\"game-error-dialog\" role=\"dialog\"> <div class=\"modal-header\"> <h4 class=\"modal-title\">Sorry!</h4> </div> <div class=\"modal-body\"> <span class=\"error-message\">{{errorMessage}}</span> </div> <div class=\"modal-footer\"> <button class=\"btn btn-info focus close-button\" (click)=\"activeModal.dismiss()\">OK </button> </div> </div>"
                },] },
    ];
    /** @nocollapse */
    DefaultActionErrorComponent.ctorParameters = function () { return [
        { type: NgbActiveModal, },
    ]; };
    DefaultActionErrorComponent.propDecorators = {
        "errorMessage": [{ type: Input },],
    };
    return DefaultActionErrorComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var DefaultActionConfirmComponent = (function () {
    function DefaultActionConfirmComponent(activeModal) {
        this.activeModal = activeModal;
    }
    DefaultActionConfirmComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngbd-modal-content',
                    template: "<div class=\"game-confirm-dialog\"> <div class=\"modal-header\"> <h4 class=\"modal-title\">{{confirmMessage}}</h4> </div> <div class=\"modal-body\"> <span class=\"confirm-message\">Are you sure?</span> </div> <div class=\"modal-footer\"> <button class=\"btn btn-danger action-button\" (click)=\"activeModal.close()\">Yes </button> <button class=\"btn btn-default focus cancel-button\" (click)=\"activeModal.dismiss()\">No </button> </div> </div> "
                },] },
    ];
    /** @nocollapse */
    DefaultActionConfirmComponent.ctorParameters = function () { return [
        { type: NgbActiveModal, },
    ]; };
    DefaultActionConfirmComponent.propDecorators = {
        "confirmMessage": [{ type: Input },],
    };
    return DefaultActionConfirmComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBModalBackdrop = (function () {
    function JTBModalBackdrop() {
    }
    JTBModalBackdrop.decorators = [
        { type: Component, args: [{
                    selector: 'jtb-modal-backdrop',
                    template: '',
                    host: {
                        'class': 'modal-backdrop fade show'
                    }
                },] },
    ];
    /** @nocollapse */
    JTBModalBackdrop.ctorParameters = function () { return []; };
    return JTBModalBackdrop;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var BootstrapBackdropService = (function () {
    function BootstrapBackdropService(_applicationRef, _injector, _componentFactoryResolver) {
        this._applicationRef = _applicationRef;
        this._injector = _injector;
        this._componentFactoryResolver = _componentFactoryResolver;
        this._backdropCount = 1;
        this._backdropFactory = _componentFactoryResolver.resolveComponentFactory(JTBModalBackdrop);
    }
    /**
     * @return {?}
     */
    BootstrapBackdropService.prototype.addBackdrop = /**
     * @return {?}
     */
    function () {
        var /** @type {?} */ containerEl = document.querySelector('body');
        this._backdropCount += 1;
        if (this._backdrop === undefined) {
            this._backdrop = this._backdropFactory.create(this._injector);
            this._applicationRef.attachView(this._backdrop.hostView);
            containerEl.appendChild(this._backdrop.location.nativeElement);
        }
    };
    /**
     * @return {?}
     */
    BootstrapBackdropService.prototype.removeBackdrop = /**
     * @return {?}
     */
    function () {
        this._backdropCount -= 1;
        if (this._backdropCount <= 1) {
            if (this._backdrop !== undefined) {
                var /** @type {?} */ backdropNativeEl = this._backdrop.location.nativeElement;
                backdropNativeEl.parentNode.removeChild(backdropNativeEl);
                this._backdrop.destroy();
                this._backdrop = undefined;
                this._backdropCount = 0;
            }
        }
    };
    BootstrapBackdropService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    BootstrapBackdropService.ctorParameters = function () { return [
        { type: ApplicationRef, },
        { type: Injector, },
        { type: ComponentFactoryResolver, },
    ]; };
    return BootstrapBackdropService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var BootstrapAdsService = (function () {
    function BootstrapAdsService(backdrop) {
        this.backdrop = backdrop;
        this.timeBetweenAds = BootstrapAdsService.DEFAULT_TIME_BETWEEN_ADS;
        this.lastAdShown = new Date(0);
    }
    /**
     * @return {?}
     */
    BootstrapAdsService.prototype.showAdPopup = /**
     * @return {?}
     */
    function () {
        var _this = this;
        var /** @type {?} */ _resolve;
        var /** @type {?} */ promise = new Promise(function (resolve, reject) {
            _resolve = resolve;
        });
        if (((new Date()).valueOf() - this.lastAdShown.valueOf()) >= this.timeBetweenAds) {
            try {
                this.backdrop.addBackdrop();
                //  TODO - actually show ad
                setTimeout(function () {
                    _this.backdrop.removeBackdrop();
                    _resolve();
                }, 1000);
            }
            catch (/** @type {?} */ ex) {
                console.error(ex);
                this.backdrop.removeBackdrop();
            }
        }
        else {
            _resolve();
        }
        return promise;
    };
    BootstrapAdsService.DEFAULT_TIME_BETWEEN_ADS = 2 * 60 * 100;
    BootstrapAdsService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    BootstrapAdsService.ctorParameters = function () { return [
        { type: BootstrapBackdropService, },
    ]; };
    return BootstrapAdsService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var BootstrapActionsService = (function () {
    function BootstrapActionsService(http$$1, router$$1, gameFactory, modalService, ads, backdrop, gameCache) {
        this.http = http$$1;
        this.router = router$$1;
        this.gameFactory = gameFactory;
        this.modalService = modalService;
        this.ads = ads;
        this.backdrop = backdrop;
        this.gameCache = gameCache;
        this.errorModal = DefaultActionErrorComponent;
        this.confirmModal = DefaultActionConfirmComponent;
    }
    /**
     * Modal must take error message public confirmMessage string in inner model
     * @param {?} modal
     * @return {?}
     */
    BootstrapActionsService.prototype.setCofirmComponent = /**
     * Modal must take error message public confirmMessage string in inner model
     * @param {?} modal
     * @return {?}
     */
    function (modal) {
        this.confirmModal = modal;
    };
    /**
     * Modal must take error message public errorMessage string in inner model
     * @param {?} modal
     * @return {?}
     */
    BootstrapActionsService.prototype.setErrorComponent = /**
     * Modal must take error message public errorMessage string in inner model
     * @param {?} modal
     * @return {?}
     */
    function (modal) {
        this.errorModal = modal;
    };
    /**
     * @param {?} httpObservable
     * @return {?}
     */
    BootstrapActionsService.prototype.takeAction = /**
     * @param {?} httpObservable
     * @return {?}
     */
    function (httpObservable) {
        var _this = this;
        var /** @type {?} */ observable = new Subject$1();
        this.backdrop.addBackdrop();
        httpObservable
            .subscribe(function (json) {
            var /** @type {?} */ game = _this.gameFactory.newGame(json);
            _this.gameCache.putGame(game);
            observable.next(game);
            _this.backdrop.removeBackdrop();
        }, function (error) {
            console.log(JSON.stringify(error));
            var /** @type {?} */ ngbModalRef = _this.modalService.open(_this.errorModal);
            ngbModalRef.componentInstance.errorMessage = error.error;
            observable.complete();
            _this.backdrop.removeBackdrop();
        });
        return observable;
    };
    /**
     * @param {?} message
     * @param {?} httpObservable
     * @return {?}
     */
    BootstrapActionsService.prototype.takeActionWithConfirm = /**
     * @param {?} message
     * @param {?} httpObservable
     * @return {?}
     */
    function (message, httpObservable) {
        var _this = this;
        var /** @type {?} */ observable = new Subject$1();
        var /** @type {?} */ ngbModalRef = this.modalService.open(this.confirmModal);
        ngbModalRef.componentInstance.confirmMessage = message;
        ngbModalRef.result.then(function () {
            _this.takeAction(httpObservable).subscribe(function (game) {
                observable.next(game);
            }, function () {
                observable.complete();
            });
        }, function () {
            observable.complete();
        });
        return observable;
    };
    /**
     * @param {?} options
     * @return {?}
     */
    BootstrapActionsService.prototype.newGame = /**
     * @param {?} options
     * @return {?}
     */
    function (options) {
        var _this = this;
        this.ads.showAdPopup().then(function () {
            _this.takeAction(_this.http.post('/api/player/new', options)).subscribe(function (game) {
                _this.router.navigateByUrl(game.standardLink());
            });
        });
    };
    /**
     * @param {?} game
     * @return {?}
     */
    BootstrapActionsService.prototype.accept = /**
     * @param {?} game
     * @return {?}
     */
    function (game) {
        var _this = this;
        this.ads.showAdPopup().then(function () {
            _this.takeAction(_this.gameAction(game, 'accept'));
        });
    };
    /**
     * @param {?} game
     * @return {?}
     */
    BootstrapActionsService.prototype.reject = /**
     * @param {?} game
     * @return {?}
     */
    function (game) {
        this.takeActionWithConfirm('Reject this game!', this.gameAction(game, 'reject'));
    };
    /**
     * @param {?} game
     * @return {?}
     */
    BootstrapActionsService.prototype.quit = /**
     * @param {?} game
     * @return {?}
     */
    function (game) {
        this.takeActionWithConfirm('Quit this game!', this.gameAction(game, 'quit'));
    };
    /**
     * @param {?} game
     * @return {?}
     */
    BootstrapActionsService.prototype.rematch = /**
     * @param {?} game
     * @return {?}
     */
    function (game) {
        var _this = this;
        this.ads.showAdPopup().then(function () {
            _this.takeAction(_this.gameAction(game, 'rematch')).subscribe(function (game) {
                _this.router.navigateByUrl(game.standardLink());
            });
        });
    };
    /**
     * @param {?} game
     * @return {?}
     */
    BootstrapActionsService.prototype.declineRematch = /**
     * @param {?} game
     * @return {?}
     */
    function (game) {
        this.takeActionWithConfirm('End this series\?', this.gameAction(game, 'endRematch'));
    };
    /**
     * @param {?} game
     * @param {?} action
     * @param {?=} body
     * @return {?}
     */
    BootstrapActionsService.prototype.gameAction = /**
     * @param {?} game
     * @param {?} action
     * @param {?=} body
     * @return {?}
     */
    function (game, action, body) {
        return this.http.put(this.gameURL(game) + action, body);
    };
    /**
     * @param {?} game
     * @return {?}
     */
    BootstrapActionsService.prototype.gameURL = /**
     * @param {?} game
     * @return {?}
     */
    function (game) {
        return '/api/player/game/' + game.id + '/';
    };
    BootstrapActionsService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    BootstrapActionsService.ctorParameters = function () { return [
        { type: HttpClient, },
        { type: Router, },
        { type: undefined, decorators: [{ type: Inject, args: ['GameFactory',] },] },
        { type: NgbModal, },
        { type: BootstrapAdsService, },
        { type: BootstrapBackdropService, },
        { type: GameCacheService, },
    ]; };
    return BootstrapActionsService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBCoreGamesUIBSAdsModule = (function () {
    function JTBCoreGamesUIBSAdsModule() {
    }
    JTBCoreGamesUIBSAdsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        FormsModule,
                        BrowserModule
                    ],
                    providers: [
                        BootstrapAdsService
                    ],
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBSAdsModule.ctorParameters = function () { return []; };
    return JTBCoreGamesUIBSAdsModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var BootstrapRerouteService = (function () {
    function BootstrapRerouteService(router$$1, gameCache) {
        var _this = this;
        this.router = router$$1;
        this.gameCache = gameCache;
        this.enabled = true;
        this.currentGameID = '';
        this.currentLocation = '';
        router$$1.events.subscribe(function (event) {
            if (_this.enabled && event instanceof NavigationEnd) {
                _this.handleNavigation(event);
            }
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    BootstrapRerouteService.prototype.handleNavigation = /**
     * @param {?} event
     * @return {?}
     */
    function (event) {
        this.updateCurrentURLFromEvent(event);
        if (this.currentLocation.indexOf('/game') === 0) {
            var /** @type {?} */ id = this.getGameIdFromURL();
            if (id !== this.currentGameID) {
                this.closeCurrentListen();
                this.startListeningForGameID(id);
            }
        }
        else {
            this.closeCurrentListen();
        }
    };
    /**
     * @param {?} event
     * @return {?}
     */
    BootstrapRerouteService.prototype.updateCurrentURLFromEvent = /**
     * @param {?} event
     * @return {?}
     */
    function (event) {
        if (event.url !== undefined && event.url !== null) {
            this.currentLocation = event.url;
        }
        else {
            this.currentLocation = '';
        }
    };
    /**
     * @return {?}
     */
    BootstrapRerouteService.prototype.getGameIdFromURL = /**
     * @return {?}
     */
    function () {
        var /** @type {?} */ parts = this.currentLocation.split('/');
        return parts[parts.length - 1];
    };
    /**
     * @return {?}
     */
    BootstrapRerouteService.prototype.closeCurrentListen = /**
     * @return {?}
     */
    function () {
        if (this.currentGameID !== '') {
            this.currentGameID = '';
            this.currentGameSubscription = undefined;
        }
    };
    /**
     * @param {?} id
     * @return {?}
     */
    BootstrapRerouteService.prototype.startListeningForGameID = /**
     * @param {?} id
     * @return {?}
     */
    function (id) {
        var _this = this;
        this.currentGameID = id;
        this.currentGameSubscription = this.gameCache.getGame(id);
        this.currentGameSubscription.subscribe(function (game) {
            if (game.id === _this.currentGameID) {
                var /** @type {?} */ expectedURL = game.standardLink();
                if (expectedURL !== _this.currentLocation) {
                    _this.router.navigateByUrl(expectedURL);
                }
            }
        });
    };
    BootstrapRerouteService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    BootstrapRerouteService.ctorParameters = function () { return [
        { type: Router, },
        { type: GameCacheService, },
    ]; };
    return BootstrapRerouteService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBCoreGamesUIBSActionsModule = (function () {
    // noinspection JSUnusedLocalSymbols
    function JTBCoreGamesUIBSActionsModule(reroute) {
        this.reroute = reroute;
    }
    JTBCoreGamesUIBSActionsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        HttpClientModule,
                        BrowserModule,
                        NgbModule,
                        FormsModule,
                        JTBCoreGamesUI,
                        JTBCoreGamesUIBSAdsModule
                    ],
                    providers: [
                        BootstrapActionsService,
                        BootstrapRerouteService
                    ],
                    entryComponents: [
                        DefaultActionConfirmComponent,
                        DefaultActionErrorComponent
                    ],
                    declarations: [
                        DefaultActionConfirmComponent,
                        DefaultActionErrorComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBSActionsModule.ctorParameters = function () { return [
        { type: BootstrapRerouteService, },
    ]; };
    return JTBCoreGamesUIBSActionsModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SignedInComponent = (function () {
    function SignedInComponent(playerService, router$$1) {
        this.playerService = playerService;
        this.router = router$$1;
        this.playerService.loadLoggedInPlayer();
        //noinspection JSIgnoredPromiseFromCall
        this.router.navigateByUrl('/main');
    }
    SignedInComponent.decorators = [
        { type: Component, args: [{
                    selector: 'signed-in',
                    template: "<div class=\"signed-in container-fluid\"> <div class=\"row text-center\"> <div class=\"col\"> <p>Login successful...</p> </div> </div> </div> ",
                },] },
    ];
    /** @nocollapse */
    SignedInComponent.ctorParameters = function () { return [
        { type: PlayerService, },
        { type: Router, },
    ]; };
    return SignedInComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBCoreGamesUIBSSignedInModule = (function () {
    function JTBCoreGamesUIBSSignedInModule() {
    }
    JTBCoreGamesUIBSSignedInModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        BrowserModule,
                        NgbModule,
                        JTBCoreGamesUI
                    ],
                    exports: [
                        SignedInComponent
                    ],
                    declarations: [
                        SignedInComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBSSignedInModule.ctorParameters = function () { return []; };
    return JTBCoreGamesUIBSSignedInModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var DefaultVersionNotesComponent = (function () {
    function DefaultVersionNotesComponent(activeModal, config) {
        this.activeModal = activeModal;
        this.config = config;
    }
    DefaultVersionNotesComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngbd-modal-content',
                    template: "<div class=\"version-dialog\"> <div class=\"modal-header\"> <h3 class=\"modal-title\">Welcome to version {{config.version}}</h3> </div> <div class=\"modal-body\"> <span class=\"version-message\">{{config.releaseNotes}}</span> </div> <div class=\"modal-footer\"> <button class=\"btn btn-info focus close-button\" (click)=\"activeModal.dismiss()\">OK </button> </div> </div> "
                },] },
    ];
    /** @nocollapse */
    DefaultVersionNotesComponent.ctorParameters = function () { return [
        { type: NgbActiveModal, },
        { type: undefined, decorators: [{ type: Inject, args: ['AppConfig',] },] },
    ]; };
    return DefaultVersionNotesComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var VersionService = (function () {
    function VersionService(config, http$$1, playerService, modalService) {
        var _this = this;
        this.config = config;
        this.http = http$$1;
        this.playerService = playerService;
        this.modalService = modalService;
        this.modalComponent = DefaultVersionNotesComponent;
        this.playerService.loggedInPlayer.subscribe(function (p) {
            _this.displayVersionNotes(p.lastVersionNotes);
        });
    }
    /**
     * Component should take in AppConfig and use version notes
     * @param {?} modalComponent
     * @return {?}
     */
    VersionService.prototype.setVersionNotesComponent = /**
     * Component should take in AppConfig and use version notes
     * @param {?} modalComponent
     * @return {?}
     */
    function (modalComponent) {
        this.modalComponent = modalComponent;
    };
    /**
     * @param {?} lastVersionForPlayer
     * @return {?}
     */
    VersionService.prototype.displayVersionNotes = /**
     * @param {?} lastVersionForPlayer
     * @return {?}
     */
    function (lastVersionForPlayer) {
        var /** @type {?} */ display = this.playerNeedsToSeeNotes(lastVersionForPlayer);
        if (display) {
            this.modalService.open(this.modalComponent);
            this.http.post('/api/player/lastVersionNotes/' + this.config.version, '')
                .subscribe(function () {
                console.log('updated player version.');
            });
        }
    };
    /**
     * @param {?} lastVersionForPlayer
     * @return {?}
     */
    VersionService.prototype.playerNeedsToSeeNotes = /**
     * @param {?} lastVersionForPlayer
     * @return {?}
     */
    function (lastVersionForPlayer) {
        var /** @type {?} */ display = false;
        if (lastVersionForPlayer !== undefined) {
            var /** @type {?} */ currentParts = this.config.version.split('.');
            var /** @type {?} */ playerParts_1 = lastVersionForPlayer.split('.');
            if (currentParts.length !== playerParts_1.length) {
                display = true;
            }
            if (display === false) {
                currentParts.forEach(function (v, index) {
                    if (parseInt(v, 10) > parseInt(playerParts_1[index], 10)) {
                        display = true;
                    }
                });
            }
        }
        return display;
    };
    VersionService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    VersionService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: ['AppConfig',] },] },
        { type: HttpClient, },
        { type: PlayerService, },
        { type: NgbModal, },
    ]; };
    return VersionService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBCoreGamesUIBSVersionNotesModule = (function () {
    // noinspection JSUnusedLocalSymbols
    function JTBCoreGamesUIBSVersionNotesModule(versionService) {
        this.versionService = versionService;
    }
    JTBCoreGamesUIBSVersionNotesModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        BrowserModule,
                        NgbModule,
                        JTBCoreGamesUI
                    ],
                    providers: [
                        VersionService
                    ],
                    entryComponents: [
                        DefaultVersionNotesComponent
                    ],
                    declarations: [
                        DefaultVersionNotesComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBSVersionNotesModule.ctorParameters = function () { return [
        { type: VersionService, },
    ]; };
    return JTBCoreGamesUIBSVersionNotesModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBCoreGamesUIBSBackdropModule = (function () {
    function JTBCoreGamesUIBSBackdropModule() {
    }
    JTBCoreGamesUIBSBackdropModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        BrowserModule
                    ],
                    declarations: [
                        JTBModalBackdrop
                    ],
                    entryComponents: [
                        JTBModalBackdrop
                    ],
                    providers: [
                        BootstrapBackdropService
                    ],
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBSBackdropModule.ctorParameters = function () { return []; };
    return JTBCoreGamesUIBSBackdropModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var DefaultErrorComponent = (function () {
    function DefaultErrorComponent(activeModal, playerService) {
        this.activeModal = activeModal;
        this.playerService = playerService;
    }
    /**
     * @return {?}
     */
    DefaultErrorComponent.prototype.dismissAndForceLogout = /**
     * @return {?}
     */
    function () {
        this.activeModal.dismiss();
        this.playerService.forceLogout();
    };
    DefaultErrorComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngbd-modal-content',
                    template: "<div class=\"general-error-dialog\" role=\"dialog\"> <div class=\"modal-header\"> <h4 class=\"modal-title\">Sorry!</h4> </div> <div class=\"modal-body\"> <span class=\"error-message\">Something has gone wrong, going to try to re-login and reset.</span> </div> <div class=\"modal-footer\"> <button class=\"btn btn-info focus close-button\" (click)=\"dismissAndForceLogout()\">OK </button> </div> </div> "
                },] },
    ];
    /** @nocollapse */
    DefaultErrorComponent.ctorParameters = function () { return [
        { type: NgbActiveModal, },
        { type: PlayerService, },
    ]; };
    return DefaultErrorComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var BootstrapErrorListenerService = (function () {
    function BootstrapErrorListenerService(messageBus, modalService) {
        var _this = this;
        this.messageBus = messageBus;
        this.modalService = modalService;
        this.listenToSessionErrors = true;
        this.listenToGeneralErrors = true;
        this.messageBus.invalidSessionError.subscribe(function () {
            if (_this.listenToSessionErrors) {
                modalService.open(DefaultErrorComponent);
            }
        });
        this.messageBus.generalError.subscribe(function () {
            if (_this.listenToGeneralErrors) {
                modalService.open(DefaultErrorComponent);
            }
        });
    }
    BootstrapErrorListenerService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    BootstrapErrorListenerService.ctorParameters = function () { return [
        { type: MessageBusService, },
        { type: NgbModal, },
    ]; };
    return BootstrapErrorListenerService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBCoreGamesUIBSErrorsModule = (function () {
    // noinspection JSUnusedLocalSymbols
    function JTBCoreGamesUIBSErrorsModule(errorListener) {
        this.errorListener = errorListener;
    }
    JTBCoreGamesUIBSErrorsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        BrowserModule,
                        NgbModule,
                        JTBCoreGamesUI
                    ],
                    providers: [
                        BootstrapErrorListenerService
                    ],
                    entryComponents: [
                        DefaultErrorComponent
                    ],
                    declarations: [
                        DefaultErrorComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBSErrorsModule.ctorParameters = function () { return [
        { type: BootstrapErrorListenerService, },
    ]; };
    return JTBCoreGamesUIBSErrorsModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var InviteComponent = (function () {
    function InviteComponent(facebookInviteService, friendService, modalRef, config) {
        var _this = this;
        this.facebookInviteService = facebookInviteService;
        this.friendService = friendService;
        this.modalRef = modalRef;
        this.config = config;
        this.invitable = [];
        this.chosen = [];
        this.friendService.invitableFriends.subscribe(function (f) {
            _this.invitable = f;
            _this.chosen = [];
        });
    }
    /**
     * @return {?}
     */
    InviteComponent.prototype.cancel = /**
     * @return {?}
     */
    function () {
        this.modalRef.dismiss();
    };
    /**
     * @return {?}
     */
    InviteComponent.prototype.inviteFriends = /**
     * @return {?}
     */
    function () {
        this.facebookInviteService.inviteFriends(this.chosen, this.config.inviteFriendsMessage);
        this.modalRef.close();
    };
    InviteComponent.decorators = [
        { type: Component, args: [{
                    selector: 'invite-friends',
                    template: "<div class=\"invite-dialog\"> <div class=\"modal-header\"> <h3 class=\"modal-title\">Invite Friends to Play</h3> </div> <div class=\"modal-body\"> <p-multiSelect [options]=\"invitable\" dataKey=\"id\" optionLabel=\"displayName\" maxSelectedLabels=\"30\" [(ngModel)]=\"chosen\" [ngModelOptions]=\"{standalone: true}\"> </p-multiSelect> </div> <div class=\"modal-footer\"> <button class=\"btn btn-primary invite-friends\" (click)=\"inviteFriends()\">Invite</button> <button class=\"btn btn-warning cancel-invite\" (click)=\"cancel()\">Cancel</button> </div> </div> ",
                },] },
    ];
    /** @nocollapse */
    InviteComponent.ctorParameters = function () { return [
        { type: FacebookInviteService, },
        { type: FriendsService, },
        { type: NgbActiveModal, },
        { type: undefined, decorators: [{ type: Inject, args: ['AppConfig',] },] },
    ]; };
    return InviteComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ɵ0$1 = window;
var JTBCoreGamesUIBInviteModule = (function () {
    function JTBCoreGamesUIBInviteModule() {
    }
    JTBCoreGamesUIBInviteModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        BrowserModule,
                        NgbModule,
                        FormsModule,
                        MultiSelectModule,
                        JTBCoreGamesUI
                    ],
                    providers: [
                        { provide: 'Window', useValue: ɵ0$1 }
                    ],
                    entryComponents: [
                        InviteComponent
                    ],
                    declarations: [
                        InviteComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBInviteModule.ctorParameters = function () { return []; };
    return JTBCoreGamesUIBInviteModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var JTBCoreGamesUIBootstrap = (function () {
    function JTBCoreGamesUIBootstrap() {
    }
    JTBCoreGamesUIBootstrap.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        JTBCoreGamesUIBSAdminModule,
                        JTBCoreGamesUIBSSignInModule,
                        JTBCoreGamesUIBSSignedInModule,
                        JTBCoreGamesUIBSActionsModule,
                        JTBCoreGamesUIBSVersionNotesModule,
                        JTBCoreGamesUIBSAdsModule,
                        JTBCoreGamesUIBSBackdropModule,
                        JTBCoreGamesUIBSErrorsModule,
                        JTBCoreGamesUIBInviteModule
                    ],
                    exports: [
                        JTBCoreGamesUIBSAdminModule,
                        JTBCoreGamesUIBSSignInModule,
                        JTBCoreGamesUIBSSignedInModule,
                        JTBCoreGamesUIBSActionsModule,
                        JTBCoreGamesUIBSVersionNotesModule,
                        JTBCoreGamesUIBSAdsModule,
                        JTBCoreGamesUIBSBackdropModule,
                        JTBCoreGamesUIBSErrorsModule,
                        JTBCoreGamesUIBInviteModule
                    ]
                },] },
    ];
    /** @nocollapse */
    JTBCoreGamesUIBootstrap.ctorParameters = function () { return []; };
    return JTBCoreGamesUIBootstrap;
}());

export { JTBCoreGamesUIBootstrap };
